import * as util from 'util';
import { getClient, addBreadcrumb } from '@sentry/core';
import { addConsoleInstrumentationHandler, severityLevelFromString } from '@sentry/utils';

/** Console module integration */
class Console  {constructor() { Console.prototype.__init.call(this); }
  /**
   * @inheritDoc
   */
   static __initStatic() {this.id = 'Console';}

  /**
   * @inheritDoc
   */
   __init() {this.name = Console.id;}

  /**
   * @inheritDoc
   */
   setupOnce() {
    // noop
  }

  /** @inheritdoc */
   setup(client) {
    addConsoleInstrumentationHandler(({ args, level }) => {
      if (getClient() !== client) {
        return;
      }

      addBreadcrumb(
        {
          category: 'console',
          level: severityLevelFromString(level),
          message: util.format.apply(undefined, args),
        },
        {
          input: [...args],
          level,
        },
      );
    });
  }
} Console.__initStatic();

export { Console };
//# sourceMappingURL=console.js.map
